@@ -219,8 +219,10 @@ class IgnoreHandler : public Handler {
 public:
 	IgnoreHandler(RModifiers mods_) : mods(mods_) {}
 	virtual void press(guint b, RTriple e) {
-		if (current_dev->master)
+		if (current_dev->master) {
+			XTestFakeMotionEvent(dpy, DefaultScreen(dpy), e->x, e->y, 0);
 			XTestFakeButtonEvent(dpy, b, true, CurrentTime);
+		}
 	}
 	virtual void motion(RTriple e) {
 		if (current_dev->master)
@@ -228,8 +230,10 @@ public:
 	}
 	// TODO: Handle Proximity
 	virtual void release(guint b, RTriple e) {
-		if (current_dev->master)
+		if (current_dev->master) {
+			XTestFakeMotionEvent(dpy, DefaultScreen(dpy), e->x, e->y, 0);
 			XTestFakeButtonEvent(dpy, b, false, CurrentTime);
+		}
 		if (!xinput_pressed.size())
 			parent->replace_child(NULL);
 	}
@@ -513,6 +517,8 @@ public:
 		replay.reset();
 	}
 	virtual void press(guint b, RTriple e) {
+		if (current_dev->master)
+			XTestFakeMotionEvent(dpy, DefaultScreen(dpy), e->x, e->y, 0);
 		click_time = 0;
 		if (remap_to) {
 			fake_core_button(remap_to, false);
@@ -569,6 +575,8 @@ public:
 			XTestFakeMotionEvent(dpy, DefaultScreen(dpy), e->x, e->y, 0);
 	}
 	virtual void release(guint b, RTriple e) {
+		if (current_dev->master)
+			XTestFakeMotionEvent(dpy, DefaultScreen(dpy), e->x, e->y, 0);
 		if (remap_to) {
 			fake_core_button(remap_to, false);
 		}
@@ -812,7 +820,9 @@ protected:
 		RStroke s = finish(0);
 
 		if (prefs.move_back.get() && !current_dev->absolute)
-			current_dev->fake_motion(orig->x, orig->y);
+			XTestFakeMotionEvent(dpy, DefaultScreen(dpy), orig->x, orig->y, 0);
+		else
+			XTestFakeMotionEvent(dpy, DefaultScreen(dpy), e->x, e->y, 0);
 
 		if (stroke_action) {
 			(*stroke_action)(s);
@@ -941,10 +951,9 @@ void icon_warning() {
 		if (m && m->type == Misc::SHOWHIDE)
 			return;
 	}
-	if (!win) {
-		show_gui = true;
+	if (!win)
 		return;
-	}
+
 	Gtk::MessageDialog *md;
 	widgets->get_widget("dialog_icon", md);
 	md->set_message(_("Tray icon disabled"));
@@ -1146,7 +1155,7 @@ std::string Main::parse_args_and_init_gtk() {
 		{0,0,0,0}
 	};
 	std::string display;
-	char opt;
+	int opt;
 	// parse --display here, before Gtk::Main(...) takes it away from us
 	opterr = 0;
 	while ((opt = getopt_long(argc, argv, "gh", long_opts1, 0)) != -1)
