@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, Thomas Jaeger <ThJaeger@gmail.com>
+ * Copyright (c) 2008-2009, Thomas Jaeger <ThJaeger@gmail.com>
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -17,20 +17,23 @@
 #define __MAIN_H__
 
 #include <string>
+#include <X11/X.h>
+
+bool is_file(std::string filename);
+bool is_dir(std::string dirname);
 
 extern std::string config_dir;
+extern const char *versions[];
 extern int verbosity;
 extern bool experimental;
 
-void clear_mods();
-
 extern "C" {
 struct _XDisplay;
 typedef struct _XDisplay Display;
 }
 
 extern Display *dpy;
-#define ROOT (DefaultRootWindow(dpy))
+extern Window ROOT;
 
 class Win;
 extern Win *win;
